@ECHO off
rem ----------------------------------------------------------
rem
rem This Windows command script creates a backup of all files
rem from AVR-CP/M hard disk image files.
rem It uses CPMCP from CPMTOOLS with a proper DISKDEFS file.
rem 
rem Martin Hepperle, April 2020
rem 
rem ----------------------------------------------------------
rem Purpose:
rem Copy all individual files from a set of AVR-CP/M 8MB
rem hard disk image to a local directory.
rem ----------------------------------------------------------
rem Result:
rem Creates a subdirectory structure like this
rem
rem +- AVR_C -+
rem |         +- 0
rem |         +- ... user number ...
rem |         +- 14
rem +- AVR_D -+
rem |         +- 0
rem |         +- ... user number ...
rem |         +- 14
rem +- AVR_ ... drive ...
rem
rem in the current directory.
rem ----------------------------------------------------------
rem Notes:
rem ----------------------------------------------------------
rem ALL THESE DIRECTORIES AND ANY EXISTING FILES IN THEM WILL 
rem BE DELETED FIRST!
rem
rem Sometimes I obtain an access error under Windows 7 after deleting
rem all files and subdirectories.
rem I guess this is the effect of some funny Windows file protection or
rem interaction with a virus scanner.
rem In this case, simply repeat the run. For me, everything works fine
rem on this second run.
rem
rem CPMCP will not be able to copy some files with names like "avr_c2\a", i.e. 
rem with the path separator character (backslash).
rem -------------------------------------------
rem ----- start of user configurable part -----
rem drive character of SD-card
SET SDCARD_DRIVE=H
	
rem the hard disk image format in "diskdefs"
SET AVR_FORMAT=avr8M
	
rem A list of arbitrary drive letters to copy
rem (for each drive there must be a image file like CPMDSK_C.IMG on the SD card)
SET DRIVE_LETTERS=C,D,E,F,G,H
rem ----- end of user configurable part -----
rem -----------------------------------------

rem avoid early expansion of variables inside loops!
SETLOCAL ENABLEDELAYEDEXPANSION

REM loop over disk image files
for %%D in (%DRIVE_LETTERS%) DO (

   REM drive character of current disk image on SD card
   REM (must have prefix CPMDSK_)
   SET AVR_DRIVE=%%D

   REM build the image file name
   SET SRC=%SDCARD_DRIVE%:\CPMDSK_!AVR_DRIVE!.IMG

   REM delete all existing directories and files
   RMDIR /S /Q AVR_!AVR_DRIVE! > NUL

   REM recreate root directory
   MKDIR AVR_!AVR_DRIVE!

   ECHO Copying files from !SRC! to AVR_!AVR_DRIVE!

   REM loop over users 0...14 in steps of 1
   for /L %%U in (0,1,14) DO (
      SET USR=%%U
      ECHO     + files for user !USR!
      rem create user directory
      MKDIR AVR_!AVR_DRIVE!\!USR!
      REM must use '*' and not '*.*' to copy ALL files
      cpmcp -f %AVR_FORMAT% !SRC! !USR!:* AVR_!AVR_DRIVE!\!USR!
   )
)
