@ECHO off
rem ----------------------------------------------------------
rem
rem This Windows command script restores a backup of all files
rem to AVR-CP/M hard disk image files.
rem It uses CPMCP from CPMTOOLS with a proper DISKDEFS file.
rem 
rem Martin Hepperle, April 2020
rem 
rem ----------------------------------------------------------
rem Purpose:
rem Copy all individual files from a set of AVR-CP/M 8MB
rem hard disk image to a local directory.
rem ----------------------------------------------------------
rem Result:
rem Creates a subdirectory structure like this
rem
rem +- AVR_C -+
rem |         +- 0
rem |         +- ... user number ...
rem |         +- 14
rem +- AVR_D -+
rem |         +- 0
rem |         +- ... user number ...
rem |         +- 14
rem +- AVR_ ... drive ...
rem
rem in the current directory.
rem ----------------------------------------------------------
rem Notes:
rem ----------------------------------------------------------
rem ALL THESE DIRECTORIES AND ANY EXISTING FILES IN THEM WILL 
rem BE DELETED FIRST!
rem
rem Sometimes I obtain an access error under Windows 7 after deleting
rem all files and subdirectories.
rem I guess this is the effect of some funny Windows file protection or
rem interaction with a virus scanner.
rem In this case, simply repeat the run. For me, everything works fine
rem on this second run.
rem
rem CPMCP will not be able to copy some files with names like "avr_c2\a", i.e. 
rem with the path separator character (backslash).
rem -------------------------------------------
rem ----- start of user configurable part -----
rem drive character of SD-card
SET SDCARD_DRIVE=D
	
rem the hard disk image format in "diskdefs"
SET AVR_FORMAT=avr8M
	
rem A list of arbitrary drive letters to copy
rem (for each drive there must be a image file like CPMDSK_C.IMG on the SD card)
SET DRIVE_LETTERS=C,D,E,F,G,H
rem ----- end of user configurable part -----
rem -----------------------------------------

rem avoid early expansion of variables inside loops!
SETLOCAL ENABLEDELAYEDEXPANSION

rem loop over disk image files
for %%D IN (%DRIVE_LETTERS%) DO (

   rem drive character of current disk image on SD card
   rem (must have prefix CPMDSK_)
   SET AVR_DRIVE=%%D

   rem build the image file name
   SET DST=%SDCARD_DRIVE%:\CPMDSK_!AVR_DRIVE!.IMG

   rem recreate root directory
   IF EXIST AVR_!AVR_DRIVE! (
      ECHO Copying files from AVR_!AVR_DRIVE! to !DST!
      rem copy empty image file
      COPY /Y CPMDSK_EMPTY.IMG !DST! > NUL:

      rem loop over users 0...14 in steps of 1
      for /L %%U IN (0,1,14) DO (
         SET USR=%%U
         REM if directory exists
         IF EXIST AVR_!AVR_DRIVE!/!USR!/. (
            SET FILE=''
            FOR %%I IN (AVR_!AVR_DRIVE!/!USR!/*) DO SET FILE=%%I
            IF !FILE! NEQ '' (
               ECHO     + files for user !USR!
               REM must use forward slashes for cpmcp
               REM must use '*' and not '*.*' to copy ALL files
               REM if a directory exists, but is empty, this will throw a message
               REM "cpmcp: can not open AVR_H/8/*: Invalid argument"
               cpmcp -f %AVR_FORMAT% !DST! AVR_!AVR_DRIVE!/!USR!/* !USR!:
            ) ELSE (
               ECHO     - directory for user !USR! is empty.
            )
         )
      )
   ) ELSE (
      ECHO source directory AVR_!AVR_DRIVE! does not exist
   )
)
